@@ -79,23 +79,23 @@ static void
 test_path_functions(void)
 {
     /* Absolute paths */
-    assert(!is_absolute(""));
+    assert(!is_absolute_path(""));
 #ifdef _WIN32
-    assert(!is_absolute("path\\test"));
-    assert(is_absolute("c:\\test"));
-    assert(!is_absolute("c:test"));
-    assert(is_absolute("c:\\"));
-    assert(is_absolute("c:/"));
-    assert(!is_absolute("c:"));
-    assert(is_absolute("\\\\foo"));
-    assert(is_absolute("\\\\?\\foo"));
-    assert(is_absolute("\\\\?\\UNC\\foo"));
-    assert(is_absolute("/foo"));
-    assert(is_absolute("\\foo"));
+    assert(!is_absolute_path("path\\test"));
+    assert(is_absolute_path("c:\\test"));
+    assert(!is_absolute_path("c:test"));
+    assert(is_absolute_path("c:\\"));
+    assert(is_absolute_path("c:/"));
+    assert(!is_absolute_path("c:"));
+    assert(is_absolute_path("\\\\foo"));
+    assert(is_absolute_path("\\\\?\\foo"));
+    assert(is_absolute_path("\\\\?\\UNC\\foo"));
+    assert(is_absolute_path("/foo"));
+    assert(is_absolute_path("\\foo"));
 #else
-    assert(!is_absolute("test/path"));
-    assert(is_absolute("/test" ));
-    assert(is_absolute("/" ));
+    assert(!is_absolute_path("test/path"));
+    assert(is_absolute_path("/test" ));
+    assert(is_absolute_path("/" ));
 #endif
 }
 
@@ -416,7 +416,7 @@ test_number_parsers(void)
     }
 
     /* Random */
-    for (unsigned k = 0; k < 10000; k++) {
+    for (unsigned int k = 0; k < 10000; k++) {
         const uint32_t x32 = rand_uint32();
         const uint64_t x64 = rand_uint64();
         int count;
@@ -432,27 +432,27 @@ test_number_parsers(void)
         assert(count > 0);
         test_parse_to(uint32_t, hex, buffer, count, x32);
         /* Hex: some garbage after */
-        buffer[count] = (char) (((unsigned) rand()) % '0');
+        buffer[count] = (char) (((unsigned int) rand()) % '0');
         test_parse_to(uint32_t, hex, buffer, count, x32);
         /* Hex: Upper case (64 bits) */
         count = snprintf(buffer, sizeof(buffer), "%"PRIX64, x64);
         assert(count > 0);
         test_parse_to(uint64_t, hex, buffer, count, x64);
         /* Hex: some garbage after */
-        buffer[count] = (char) (((unsigned) rand()) % '0');
+        buffer[count] = (char) (((unsigned int) rand()) % '0');
         test_parse_to(uint64_t, hex, buffer, count, x64);
         /* Decimal (32 bits) */
         count = snprintf(buffer, sizeof(buffer), "%"PRIu32, x32);
         assert(count > 0);
         test_parse_to(uint32_t, dec, buffer, count, x32);
         /* Decimal: some garbage after */
-        buffer[count] = (char) (((unsigned) rand()) % '0');
+        buffer[count] = (char) (((unsigned int) rand()) % '0');
         test_parse_to(uint32_t, dec, buffer, count, x32);
         /* Decimal (64 bits) */
         count = snprintf(buffer, sizeof(buffer), "%"PRIu64, x64);
         assert(count > 0);
         test_parse_to(uint64_t, dec, buffer, count, x64);
-        buffer[count] = (char) (((unsigned) rand()) % '0');
+        buffer[count] = (char) (((unsigned int) rand()) % '0');
         test_parse_to(uint64_t, dec, buffer, count, x64);
     }
 }
